@@ -23,7 +23,8 @@
 
 #include "BoardKey.h"
 
-class AlphaNumKey: public BoardKey {
+class AlphaNumKey: public BoardKey
+{
 
 
 public:
@@ -31,14 +32,14 @@ public:
     virtual ~AlphaNumKey();
 
     virtual QString label() const;
-    virtual void paint(QPainter *painter);    
+    virtual void paint(QPainter *painter);
 
     /**
       * Sets button text regarding the key level
       */
     void setLabel(int level);
     void setLabel(const QString &label);
-    void switchKey(bool isLevel2, bool isAlternative, bool isLocked); 
+    void switchKey(bool isLevel2, bool isAlternative, bool isLocked);
 
 protected:
     virtual void paintLabel(QPainter *painter);
